Research with LensKit
=====================

LensKit is intended to be particularly useful in recommender systems research.

.. _citation:

Publishing with LensKit
~~~~~~~~~~~~~~~~~~~~~~~

If you use LensKit in published research (including theses, dissertations, and
preprints), please do the following:

1. Cite our paper [LKPY]_ (detailed citation below).

2. Specify the version of LensKit you are using in the paper, either in the
   text, a footnote, or as a reference.  If you cite a specific LensKit version
   as a reference, we ask that you do so in addition to the main paper, not as a
   substitute for the paper.

3. E-mail a copy of your published paper and bibliographic information to
   ekstrand@acm.org with the subject heading “Research using LensKit”, so
   we can add it to the list of :ref:`papers-using-lenskit`.

Keeping thorough records of how LensKit has been used in research helps
demonstrate the project's impact for performance reviews, grant applications,
etc. Aside from spreading the word about LensKit and contributing code, it is
one of the most important things you can do to support the project.

.. admonition:: Citation
    :class: info

    .. [LKPY]
        Michael D. Ekstrand. 2020.
        LensKit for Python: Next-Generation Software for Recommender Systems Experiments.
        In *Proceedings of the 29th ACM International Conference on Information and Knowledge Management* (CIKM '20).
        DOI:`10.1145/3340531.3412778 <https://dx.doi.org/10.1145/3340531.3412778>`_.
        arXiv:`1809.03125 <https://arxiv.org/abs/1809.03125>`_ [cs.IR].

.. admonition:: BibTeX
    :class: hint dropdown

    .. code:: bibtex

        @inproceedings{LKPY,
            title={LensKit for Python: Next-Generation Software for Recommender Systems Experiments},
            booktitle={Proceedings of the 29th ACM International Conference on Information and Knowledge Management},
            DOI={10.1145/3340531.3412778},
            author={Ekstrand, Michael D.},
            year={2020},
            month={Oct},
            extra={arXiv:1809.03125}
        }


.. toctree::
    :hidden:

    papers
    java-papers
